@@ -3,6 +3,7 @@
 # Copyright © 2013 Niels Thykier <niels@thykier.net>
 # Copyright © 2013 gregor herrmann <gregoa@debian.org>
 # Copyright © 2014 Niko Tyni <ntyni@debian.org>
+# Copyright © 2018 Florian Schlichting <fsfs@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -47,6 +48,14 @@ sub run {
     if ( $info->field('testsuite') ne 'autopkgtest-pkg-perl' )
     {
         tag 'nonteam-testsuite-header', $info->field('testsuite');
+        return;
+    }
+
+    if ( !($info->index('META.json') && $info->index('META.json')->size)
+        && !($info->index('META.yml') && $info->index('META.yml')->size)
+        && !$info->index('debian/tests/pkg-perl/use-name')
+    ) {
+        tag 'autopkgtest-needs-use-name';
     }
     return;
 }
