@@ -49,7 +49,7 @@ sub run {
     foreach my $field_name (@non_git_vcs_fields,
                             qw(vcs-git vcs-browser)) {
         my $field_value = $info->field($field_name);
-        if (defined($field_value) && $field_value !~ /pkg-perl/i) {
+        if (defined($field_value) && $field_value !~ m{^https://salsa.debian.org/perl-team/modules/packages}i) {
             tag 'vcs-url-not-under-pkg-perl', "$field_value";
         }
     }
